@@ -1,4 +1,7 @@
-from skyflow.errors._skyflowerrors import SkyflowError, SkyflowErrorCodes, SkyflowErrorMessages
+'''
+	Copyright (c) 2022 Skyflow, Inc.
+'''
+from skyflow.errors._skyflow_errors import SkyflowError, SkyflowErrorCodes, SkyflowErrorMessages
 import asyncio
 from aiohttp import ClientSession, request
 import json
